#!/usr/bin/env python3

import os
import sys

if len(sys.argv) == 1:
    commit_message = input("Commit message? ")
else:
    commit_message = " ".join(sys.argv[1:])

clean_commit_message = commit_message.replace("'", "'\\''")

os.system("git add .")
os.system(f'git commit -m "{clean_commit_message}"')
os.system("bump2version patch")
os.system("git push")
os.system("flit publish")



"""Simple python client for the capspire IMS Server"""

__version__ = "0.1.1"
from datetime import datetime
from loguru import logger
from tenacity import retry, stop_after_attempt, wait_fixed
from dateutil.parser import parse
import requests

from os import getenv


class InventoryManagementServer:
    def __init__(self, base_url=None, system_psk=None):
        self.base_url = base_url or getenv("IMS_URL")
        self.system_psk = system_psk or getenv("SYSTEM_PSK")

    @property
    def params(self):
        return {"system_psk": self.system_psk}

    @logger.catch(reraise=True)
    @retry(reraise=True, stop=stop_after_attempt(3), wait=wait_fixed(5))
    def readings(self, store, tank, start: datetime, end: datetime = None):
        params = {
            **self.params,
            "store_number": store,
            "tank_id": str(tank),
            "start_date": start.isoformat(),
        }

        if end:
            params["end_data"] = end.isoformat()
        r = requests.post(f"{self.base_url}/tank_inventory/readings", params=params)
        data = r.json() if r.status_code == 200 else []
        for row in data:
            row["read_time"] = parse(row["read_time"])
            row["run_time"] = parse(row["run_time"])
        return data

    @logger.catch(reraise=True)
    @retry(reraise=True, stop=stop_after_attempt(3), wait=wait_fixed(5))
    def tanks(self, store="", tank=""):
        params = {
            **self.params,
            "store_number": store,
            "tank_id": str(tank),
        }
        r = requests.post(f"{self.base_url}/tank/tanks", params=params)
        return r.json()



#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['ims_client']

package_data = \
{'': ['*']}

install_requires = \
['loguru', 'tenacity']

extras_require = \
{'dev': ['pytest-watch', 'tomlkit', 'black'], 'test': ['pytest', 'pytest-cov']}

setup(name='ims_client',
      version='0.1.1',
      description='Simple python client for the capspire IMS Server',
      author='James Vogel',
      author_email='jim.m.vogel@gmail.com',
      url=None,
      packages=packages,
      package_data=package_data,
      install_requires=install_requires,
      extras_require=extras_require,
      python_requires='>=3.5',
     )
